#!/bin/sh 
#
# snmpd	This shell script takes care of starting and stopping
#	the net-snmp SNMP daemon
#


SNMPCONFPATH=/etc/sma/snmp:/var/sma_snmp
MIBDIRS=/etc/sma/snmp/mibs
ZONENAME=`/usr/bin/zonename`

export SNMPCONFPATH
export MIBDIRS

name="snmpd"
prog="/usr/sfw/sbin/snmpd"

start() {
SNMPD_FILE=/etc/sma/snmp/snmpd.conf

   if [ -f ${SNMPD_FILE} -a -x /usr/sfw/sbin/snmpd ]; then
    if /usr/bin/egrep  '#DISABLE=YES' ${SNMPD_FILE} > \
                    /dev/null 2>&1; then
			exit 0
                else
                        #
                        # Do not start snmpd if #DISABLE=YES exists
                        # in the snmpd.conf file
                        #
                       $prog &
                fi
	fi
}

stop() {

# Stop daemon.
#if file exists then the daemon is still running
# otherwise it has been stopped.

	if [ -f /var/sma_snmp/.sma.pid ]; then
		pid=`cat /var/sma_snmp/.sma.pid`
		kill -TERM ${pid}
	elif [ ! -f /var/sma_snmp/.sma.pid ]; then
		# no pid but may be running anyway
		# if they started up /usr/sfw/sbin/snmpd
		# via command line

		sma=`ps -ef -o pid,' ',comm,zone | grep /usr/sfw/sbin/snmpd | grep $ZONENAME |	awk '{print $1}'`

		if [ $sma ]; then
			kill -TERM ${sma}
		fi
	fi

	return
}

status() {

# if file exists, then get the PID

	sma=`ps -ef -o pid,' ',comm,zone | grep /usr/sfw/sbin/snmpd`

	if [ -f /var/sma_snmp/.sma.pid ]; then
		sma=`cat /var/sma_snmp/.sma.pid`
		echo ""
		echo "$name running under PID $sma"
		echo ""
		exit 0
	elif [ ! -f /var/sma_snmp/.sma.pid ]; then
			# no pid but may be running anyway
			# if they started up /usr/sfw/sbin/snmpd
			# via command line

       		sma=`ps -ef -o pid,' ',comm,zone | grep /usr/sfw/sbin/snmpd | grep $ZONENAME |	awk '{print $1}'`
	
			if [ $sma ]; then
				echo ""
				echo "$name running under PID $sma"
				echo ""
				exit 0
			fi

		echo ""
		echo "$name not currently running in $ZONENAME zone"
		echo ""
		exit 0
        fi
}

# See how we were called.
case "$1" in
  start)
	start
        ;;
  stop)
	stop
        ;;
  status)
	status $name
	;;
  restart)
	stop
	start
	;;
  *)

        echo ""
	echo "\tUsage: $0 { start | stop | restart | status }"
	echo ""
        exit 1
esac

exit 0
